# simframe

Framework for scientific simulations

`simframe` is a framework to flexibly build scientific simulations.  
It comes with a variety of integration schemes and some infrastrcuture for writing and reading data files.

## Installation

`pip install simframe`

## Documentation

[https://simframe.readthedocs.io/](https://simframe.readthedocs.io/)

1. [Simple Integration](https://simframe.readthedocs.io/en/latest/1_simple_integration.html)
2. [Advanced Integration](https://simframe.readthedocs.io/en/latest/2_advanced_integration.html)
3. [Updating Groups and Fields](https://simframe.readthedocs.io/en/latest/3_updating.html)
4. [Custom Integration Schemes](https://simframe.readthedocs.io/en/latest/4_custom_schemes.html)
5. [Adaptive Integration Schemes](https://simframe.readthedocs.io/en/latest/5_adaptive_schemes.html)
6. [Implicit Integration](https://simframe.readthedocs.io/en/latest/6_implicit_integration.html)
7. [Coupled Oscillators](https://simframe.readthedocs.io/en/latest/7_coupled_oscillators.html)

[Module Reference](https://simframe.readthedocs.io/en/latest/api.html)

## Ackowledgements

`simframe` has received funding from the European Research Council (ERC) under the European Union’s Horizon 2020 research and innovation programme under grant agreement No 714769.

`simframe` was developed at the [University Observatory](https://www.usm.uni-muenchen.de/index_en.php) of the [Ludwig Maximilian University of Munich](https://www.en.uni-muenchen.de/index.html).